#
# spec file for package f3d
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define c_lib   libf3d2
Name:           f3d
Version:        2.5.1
Release:        1.2
Summary:        Fast and minimalist 3D viewer
License:        BSD-3-Clause
Group:          Productivity/Graphics/Viewers
URL:            https://f3d.app
Source0:        https://github.com/%{name}-app/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         help.patch
BuildRequires:  cmake
BuildRequires:  fast_float-devel
BuildRequires:  fmt-devel
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  cmake(Alembic)
BuildRequires:  cmake(Imath)
BuildRequires:  cmake(OpenCASCADE)
BuildRequires:  cmake(vtk) >= 9.3
BuildRequires:  pkgconfig(assimp)
BuildRequires:  pkgconfig(draco)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xt)
%if 0%{?sle_version} >= 150400
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif

%description
F3D is a VTK-based 3D viewer following the KISS principle, so it is
minimalist, efficient, has no GUI, has simple interaction mechanisms and is
fully controllable using arguments in the command line.

%package        bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description    bash-completion
Bash command line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description    fish-completion
Fish command line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description    zsh-completion
ZSH command line completion support for %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{c_lib} = %{version}

%description devel
Development files and headers for %{name}

%package -n %{c_lib}
Summary:        F3d library
Group:          System/Libraries

%description -n %{c_lib}
Library for f3d.

%prep
%autosetup -p1

%build
%cmake \
%if 0%{?suse_version} < 1600
    -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name} \
%endif
    -DCMAKE_SKIP_INSTALL_RPATH=ON \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
    -DBUILD_TESTING=OFF \
    -DF3D_BINDINGS_JAVA=OFF \
    -DF3D_BINDINGS_PYTHON=OFF \
    -DF3D_LINUX_APPLICATION_LINK_FILESYSTEM=ON \
    -DF3D_LINUX_GENERATE_MAN=ON \
    -DF3D_LINUX_INSTALL_DEFAULT_CONFIGURATION_FILE_IN_PREFIX=ON \
    -DF3D_MODULE_EXTERNAL_RENDERING=OFF \
    -DF3D_MODULE_RAYTRACING=OFF \
    -DF3D_PLUGINS_STATIC_BUILD=OFF \
%if 0%{?sle_version} >= 150400
    -DCMAKE_CXX_COMPILER=%{_bindir}/g++-11 \
%endif
    -DF3D_PLUGIN_BUILD_ALEMBIC=ON \
    -DF3D_PLUGIN_BUILD_ASSIMP=ON \
    -DF3D_PLUGIN_BUILD_DRACO=OFF \
    -DF3D_PLUGIN_BUILD_EXODUS=ON \
    -DF3D_PLUGIN_BUILD_OCCT=ON
%cmake_build

%install
%cmake_install
rm -rfv %{buildroot}%{_docdir}/f3d

# this is needed so f3d autoloads the plugins for those filetypes specified in the configs
mkdir -p %{buildroot}%{_sysconfdir}/f3d/config.d
install -Dm644 plugins/assimp/configs/config.d/10_assimp.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_assimp.json
install -Dm644 plugins/alembic/configs/config.d/10_alembic.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_alembic.json
install -Dm644 plugins/exodus/configs/config.d/10_exodus.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_exodus.json
install -Dm644 plugins/native/configs/config.d/10_native.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_native.json
install -Dm644 plugins/occt/configs/config.d/10_occt.json %{buildroot}%{_sysconfdir}/f3d/config.d/10_occt.json

%post -n %{c_lib} -p /sbin/ldconfig
%postun -n %{c_lib} -p /sbin/ldconfig

%files
%doc README.md
%license LICENSE.md doc/THIRD_PARTY_LICENSES.md
%{_bindir}/%{name}
%{_libdir}/lib%{name}-plugin-*.so
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-plugin-*.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/plugins
%{_datadir}/%{name}/plugins/*.json
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%{_datadir}/metainfo/app.%{name}.F3D.metainfo.xml
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/%{name}*.thumbnailer
%{_mandir}/man?/%{name}.?%{?ext_man}
%dir %{_sysconfdir}/f3d
%dir %{_sysconfdir}/f3d/config.d
%config %{_sysconfdir}/f3d/config.d/*.json
%{_libdir}/libvtkext.so

%files devel
%doc README.md
%license LICENSE.md doc/THIRD_PARTY_LICENSES.md
%{_libdir}/lib%{name}.so

%files -n %{c_lib}
%{_libdir}/lib%{name}.so.*

%files bash-completion
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Thu Jan  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 2.5.1:
  * Fix build compatibility with vtk v9.4.0
* Tue Jul  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.5.0:
  For F3D users:
  * Added a Webassembly version available online: https://f3d.app/web
  * Added a "neutral" tone mapping feature
  * Added an screenshot feature when pressing F12, with its dedicated option, --screenshot-filename
  * Added a --final-shader option to customize post-processing.
  * Added a --grid-color option to set the color of the grid
  * Added a --animation-progress option to control if the animation progress bar should be shown
  * Added a --backface-type option to control backface visibility
  * Added a concept of filename template for saving screenshots and outputs
  * Added native menus for macOS
  * Improved documentation all around
  * Reworked config file logic to avoid duplicating of the default config
  * Fixed a long standing issue with FBX skinning animation
  * Fixed zsh completion
  * Fixed an opacity blending issue
  * Fixed a crash when dropping a HDRI while playing an animation
  * Fixed a focus issue on macOS
  * Fixed a high DPI issue on Windows
  For libf3d users:
  * Added an API to control camera pan and zoom
  * Added a tkinter python example
  * Exposed log level in the python API
  For F3D packagers:
  * Fixed compatibility with CMake 3.29.1
  * Fixed compatibility with OCCT 7_8_0
  * Fixed build reproducability by removing a path from the binary
- Add help.patch to fix the build
- Dont manually remove libVTKExtensions*.a. Not needed with
  vtk >= 9.3
* Thu Apr  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.4.0:
  For F3D users:
  * Added a new option --point-type used to specify how to display points sprites
  * Add support for 3D Gaussians Splatting in binary .splat format
  * Added ability to cycle through available animations by pressing W hotkey
  * Added display of current animation name within cheatsheet
  * Added orthographic camera projection option (--camera-orthographic) and binding (5)
  * Added proper continuous integration for MacOS ARM64
  * Added support for glTF Draco encoded file
  * Added support for dark title bar on Windows
  * Added support for colormap presets, using --colormap-file option
  * Added a option to reload file automatically when changed on disk (--watch)
  * Added support for streaming output images to stdout, using - filename
  * Added animation support to Alembic plugin
  * Improved OCCT plugin (STEP and IGES files) performance drastically
  * Improved config file parsing so that it is parsed in file order
  * Fixed an issue with blur circle of confusion
  * Fixed an issue with the grid being clipped
  * Fixed an issue with STEP file coloring
  * Fixed an issue when time range was not starting at zero
  * Fixed an issue when record file does not exist
  * Fixed an issue when using --no-render and --hdri
  * Fixed an issue with the Windows thumbnailer with process never properly killed
  * Fixed an issue where OCCT would output to terminal
  * Fixed an issue with FISH completion
  For libf3d users:
  * Added a new option model.point-sprites.type used to specify how
    to display points (only if model.point-sprites.enable is true)
  * Added a image::toTerminalText method to print image to terminal text
  * Added an image metadata API
  * Added a vtkext module for plugin developer, see the documentation
  For F3D packagers:
  * Added a CMake report at the end of configuration
  * Fixed multiple issue with static (BUILD_SHARED_LIBS=OFF) build
  * Fixed a compilation issue with gcc14
  * Fixed a compilation issue with OCCT 7.8.0
* Fri Mar 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.3.1:
  * Added --animation-autoplay option (libf3d: scene.animation.autoplay)
    to automatically start animation on file load
  * Added an experimental vdb plugin in order to read .vdb files using OpenVDB
  * Added an usd plugin in order to read .usd files using OpenUSD
  * Added .3mf and .x files support in the assimp plugin
  * Added a small margin between the model and the grid to avoid potential z-fighting
  * Added VTK output to the log when using --verbose=debug for easier debug
  * Reworked the alembic plugin to read Texture Coordinates and Normals for .abc files
  * Improved the reading of EXR files using multi-threading for better performance when loading HDRIs
  * Improved the documentation on https://f3d.app
  * Improved general logging in order to make it easier to understand issues with file and options
  * Fixed potential crashes when reading assimp plugin file formats
  * Fixed --grid-absolute for off-center models
  * Fixed an issue with thumbnail generation showing the log window
  * Fixed many interaction issues on non-Qwerty keyboard layout
  * Fixed handling of filenames containing commas
  * Fixed an issue on Windows where the log window would appear on top of F3D window
  * Fixed crashes with specific .obj file
  * Fixed an issue with incorrect return code when using headless mode or incorrect options
  * Fixed dependency issue with the headless .deb binary release
  * Fixed a crash when using a file with more than 254 bones (Requires OpenGL 4.3)
  * Fixed an issue with Unicode filenames on the title bar on Windows
  * Fixed an issue where focal point picking would generate error messages
  * Changed --verbose into a string based option, eg: --verbose=quiet or
  - -verbose=debug. --verbose is still supported.
  * Changed --no-render behavior so that it doesn't impact verbosity anymore
  * Changed the default configuration file so that translucency support is enabled by default
  * Deprecated --quiet, use --verbose=quiet instead
  * Deprecated --input, use positional argument instead
* Tue Feb 27 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Use the correct documentation's path
* Mon Jan 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.3.0:
  For F3D users:
  * Added --animation-autoplay option (libf3d: scene.animation.autoplay) to automatically start animation on file load
  * Added an experimental vdb plugin in order to read .vdb files using OpenVDB
  * Added an usd plugin in order to read .usd files using OpenUSD
  * Added .3mf and .x files support in the assimp plugin
  * Added a small margin between the model and the grid to avoid potential z-fighting
  * Added VTK output to the log when using --verbose=debug for easier debug
  * Reworked the alembic plugin to read Texture Coordinates and Normals for .abc files
  * Improved the reading of EXR files using multi-threading for better performance when loading HDRIs
  * Improved the documentation on https://f3d.app
  * Improved general logging in order to make it easier to understand issues with file and options
  * Fixed potential crashes when reading assimp plugin file formats
  * Fixed --grid-absolute for off-center models
  * Fixed an issue with thumbnail generation showing the log window
  * Fixed many interaction issues on non-Qwerty keyboard layout
  * Fixed handling of filenames containing commas
  * Fixed an issue on Windows where the log window would appear on top of F3D window
  * Fixed crashes with specific .obj file
  * Fixed an issue with incorrect return code when using headless mode or incorrect options
  * Fixed dependency issue with the headless .deb binary release
  * Fixed a crash when using a file with more than 254 bones (Requires OpenGL 4.3)
  * Fixed an issue with Unicode filenames on the title bar on Windows
  * Fixed an issue where focal point picking would generate error messages
  * Changed --verbose into a string based option, eg: --verbose=quiet or --verbose=debug. --verbose is still supported.
  * Changed --no-render behavior so that it doesn't impact verbosity anymore
  * Changed the default configuration file so that translucency support is enabled by default
  * Deprecated --quiet, use --verbose=quiet instead
  * Deprecated --input, use positional argument instead
  For libf3d users:
  * Added scene.animation.autoplay option
  * Added a f3d::image::saveBuffer API to save an image as a file format in memory
  * Fixed the default name of the window
- Remove f3d.rpmlintrc
* Wed Jan 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.2.1:
  * Added new options hdri-file, hdri-ambient, hdri-skybox to have more control on the HDRI behavior
  * Added a default HDRI used when providing no hdri-file
  * Added bindings to toggle HDRI ambient lighting (F) and HDRI skybox (J)
  * Added bindings to move the camera to standard locations: 1: Front, 3: Right, 7: Top, 9: Isometric
  * Added Open CASCADE BRep format to the OCCT plugin.
  * Fixed an infamous issue when the Windows thumbnailer always steal the focus
  * Fixed an issue with the binary release when opening draco files
  * Fixed an issue with matcap textures
  * Fixed an issue with HDRI lighting
  * Fixed an issue with HDRI lighting when dropping HDRI after a model
  * Fixed an issue where invalid option would not show on Windows
  * Fixed an issue where previously loaded file would stay visible
  * Fixed an issue when loading invalid EXR file as HDRI
  * Fixed cheatsheet menu rendering under ‘Drop File Instructor’
  * Fixed raytracing rendering issues
  * Improved cheatsheet menu contrast for any background color
  * Improved overall text contrast for any background color
  * Improved performance when changing model and using a HDRI
  * Improved HDRI cache performance
  * Deprecated hdri option
  * Reworked image API to support many file formats to read (EXR, HDR) and write (PNG, JPG, TIF, BMP)
  * Added render.hdri.file, render.hdri.ambient, render.background.skybox options.
  * Deprecated render.background.hdri in favor of new options above
  * Deprecated previous image API
  * Add loader::loadGeometry allowing loading geometry from memory buffers
  * Added a deprecation framework
  * Removed F3D_TESTING_ENABLE_HDRI_TESTS cmake option and merged it with F3D_TESTING_ENABLE_LONG_TIMEOUT_TESTS
  * Added a Getting Started guide for beginners developers
* Wed Jan 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 2.1.0:
  * Reworked Animation support and added many animation related options
  * Added --camera-direction and --camera-zoom-factor and use it in default config file
  * Added --texture-matcap option to load a MatCap texture
  * Added support for opening HDRI background with Drop
  * Added .exr support for HDRI and textures
  * Improved HDRI caching performance
  * Added a EGL headless binary release
  * Added typo suggestion when failing to use the right option name
  * Added --invert-zoom option (libf3d: interactor.invert-zoom) to invert
    zoom direction with right-click on mouse
  * Added support for keeping camera position when reloading a file with UP key
  * Added a --grid-absolute option (libf3d: render.grid.absolute) to
    position the grid instead of being below the model
  * Added a “Drop Zone” when starting F3D without loading a file
  * Added coloring support for STEP files in binary release
  * Fixed an issue on Windows where the error window would popup even with --quiet
  * Fixed an issue with 16 bit and 32 bit textures with assimp plugin
  * Fixed an issue on Windows where errors where not visible
  * Fixed an HDRI issue on reload
  * Fixed a crash when with the progress bar on reloading a file
  * Fixed an issue where certain options from config file would be ignored
  * Fixed a crash with many GLTF files when an array does not have a name
  * Fixed an issue where dropping a duplicate file would change the loaded
    file instead of not doing anything
  * Fixed an issue when loading an unsupported file
  * Fixed an issue with VRML files
  * Improved config file for .ply files
  * Improved config file regex so that they are case-insensitive
  * Improved --up option to support no sign and better validation
  * Improved F3D version reporting about itself and VTK (--version)
  * Improved documentation, testing, help
  * Changed the automatic camera position to a version more close to the data
  * Reduced size of binary release by a factor of two
  * Added vcpkg support for dependency installation
  * Added a F3D_PLUGIN_OCCT_COLORING_SUPPORT CMake variable to control if this
    feature is compiled, default is ON
  * Added SONAME support
  * Added a F3D_PLUGINS_INSTALL_DIR CMake variable to control where to install plugins
  * Added a new module: F3D_MODULE_EXR that depends on openexr
  * Added support to use external cxxopts and external nlohmann-json
  * Fixed a link issue with VTK modules
  * Fixed a @loader_path issue on MacOS
  * Added support for CMAKE_INSTALL_*DIR variables on installation
  * Added support for building against a EGL enabled VTK
  * Fixed a compilation issue with VTK master
- Add build requires for fmt-devel and fast_float-devel
- Set -DF3D_PLUGIN_BUILD_DRACO=OFF for now to fix the build
- Use -DCMAKE_SKIP_INSTALL_RPATH=ON to fix `No valid ELF RPATH or RUNPATH
  entry exists in the file` build failure
- Split out libf3d into subpackage
* Thu Jun 22 2023 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.0.0:
  * Update F3D Version to 2.0.0 (#744)
  * reorder sections
  * Update LIMITATIONS_AND_TROUBLESHOOTING.md
  * Update copyright year (#742)
  * Update F3D Version to 2.0.0-RC3 (#740)
  * Add a test against segfault (#738)
  * Add doc about unsigned packages (#739)
  * Fix a segfault with down interaction (#737)
  * Update F3D version to RC2 (#736)
  * Fix and update doc (#735)
* Wed Dec 15 2021 Андрей Алыпов <and.november@opensuse.org>
- Update to version 1.2.1
  * Fix format list in documentation
  * typo
  * Fixup
  * initialize quiet
  * Respect output window conf
  * Improving .deb package
  * Handle readers with CMake
  * Rerun failing tests in serial
  * Fix link in readme
  * Added the missing CPACK_PACKAGE_CONTACT
  * Added DEB to cPack generator
  * Fix useless whatis entry in man page.
  * Add shadow warning during strict compil
  * Fix Shadowing
  * Reindent file
  * fix name
  * Improve installation doc
  * SSAO in long timeout to avoid failure on macos
  * Updating VTK for https://gitlab.kitware.com/vtk/vtk/-/merge_requests/8682/
  * Fix an error in codecov conf
  * typo
  * Adding spack package
  * Update website again
  * Adding more badges
* Wed Jul  8 2020 Андрей Алыпов <and.november@opensuse.org>
- initial package (version 1.1.0) for openSUSE
